@@ -131,6 +131,7 @@ add_provider_to_list (GisGoaPage *page, const char *provider_type)
 
   row = gtk_list_box_row_new ();
   box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+  g_object_set (box, "margin", 4, NULL);
   gtk_widget_set_hexpand (box, TRUE);
 
   icon = goa_provider_get_provider_icon (provider, NULL);
@@ -286,16 +287,18 @@ gis_goa_page_constructed (GObject *object)
 
   G_OBJECT_CLASS (gis_goa_page_parent_class)->constructed (object);
 
+  gis_page_set_skippable (GIS_PAGE (page), TRUE);
+
+  priv->providers = g_hash_table_new (g_str_hash, g_str_equal);
+
   priv->goa_client = goa_client_new_sync (NULL, &error);
 
   if (priv->goa_client == NULL) {
-    g_error ("Failed to get a GoaClient: %s", error->message);
+    g_warning ("Failed to get a GoaClient: %s", error->message);
     g_error_free (error);
     return;
   }
 
-  priv->providers = g_hash_table_new (g_str_hash, g_str_equal);
-
   g_signal_connect (priv->goa_client, "account-added",
                     G_CALLBACK (accounts_changed), page);
   g_signal_connect (priv->goa_client, "account-removed",
@@ -311,8 +314,6 @@ gis_goa_page_constructed (GObject *object)
 
   populate_provider_list (page);
   sync_accounts (page);
-
-  gis_page_set_skippable (GIS_PAGE (page), TRUE);
 }
 
 static void
